# -*- coding: utf-8 -*-
from setuphelpers import *
import platform
import bs4 as BeautifulSoup

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
package_name = "seadrive-gui"


def install():
    # Installing the package
    print("Installing: %s" % package_name)

    if isfile("/etc/apt/sources.list.d/seadrive.list"):
        remove_file("/etc/apt/sources.list.d/seadrive.list")

    update_apt()
    install_apt("apt-transport-https")
    install_apt("ca-certificates")
    run("wget https://linux-clients.seafile.com/seafile.asc -O /usr/share/keyrings/seafile-keyring.asc")
    run(
        "bash -c \"echo 'deb [arch=amd64 signed-by=/usr/share/keyrings/seafile-keyring.asc] https://linux-clients.seafile.com/seadrive-deb/$(lsb_release -c -s)/ stable main ' > /etc/apt/sources.list.d/seadrive.list\""
    )
    install_apt(package_name)


def uninstall():
    # Uninstalling the package
    print("Uninstalling %s" % package_name)
    uninstall_apt(package_name)
    uninstall_apt("seadrive-daemon")


def update_package():
    result = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    url = "https://manual.seafile.com/changelog/drive-client-changelog/"
    version = control.get_software_version()

    """ for u in bs_find_all(url,'li', proxies=proxies):
    # Getting latest version from official website
    #for u in bs_find_all(url,'h3', proxies=proxies):
        if '[Linux]' in u.text:
            previous_element = u.previous_element
            good_version = False
            while(not good_version):
                if previous_element.name =='h3':
                    latest_version = previous_element.text.split(' ')[0]
                    good_version=True
                else:
                    previous_element = previous_element.previous_element

    import requests
    page = requests.get(url, proxies=proxies).text
    soup = BeautifulSoup.BeautifulSoup(page)
    soup.find_all('h3')

    print("Latest %s version is: %s" % (app_name, version))
    print("Download URL is: %s" % download_url) """

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        result = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.version = "%s-%s" % (Version(version), control.version.split("-", 1)[-1])
    # control.set_software_version(version)
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating update-package-sources
    return result
